# limit parallel builds
%ifarch aarch64 x86_64
%global _smp_ncpus_max 4
%endif

%define uversion 2021.01
%define version %(echo %{uversion} | tr '-' '.')

Name:           openscad
Version:        %{version}
%define subrel 2
Release:        %mkrel 1
Summary:        The Programmers Solid 3D CAD Modeller
# COPYING contains a linking exception for CGAL
# AppData is CC0
License:        GPLv2 with exceptions and CC0
Group:          Graphics/3D
URL:            http://www.openscad.org/
Source0:        http://files.openscad.org/%{name}-%{name}-%{uversion}.tar.gz
Patch0:         openscad-polyclipping.patch
Patch1:         openscad-lib3mf.patch
#
# Security patches:
# P100 -> ...
#
# CVE-2020-28599
#Patch100:	07ea60f82e94a155f4926f17fad8e8366bc74874.patch
BuildRequires:  bison
BuildRequires:  git
BuildRequires:  boost-devel
BuildRequires:  cgal-devel
BuildRequires:  cmake
BuildRequires:  flex
BuildRequires:  imagemagick
BuildRequires:  gmp-devel
BuildRequires:  opencsg-devel
BuildRequires:  cmake(double-conversion)
BuildRequires:  pkgconfig(mpfr)
BuildRequires:  pkgconfig(eigen3)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(harfbuzz)
BuildRequires:  pkgconfig(lib3mf)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(libzip)
BuildRequires:  pkgconfig(polyclipping)
BuildRequires:  pkgconfig(python3)
BuildRequires:  qscintilla-qt5-devel
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gamepad)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Multimedia)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  x11-server-xvfb

%description
OpenSCAD is a software for creating solid 3D CAD objects.
Unlike most free software for creating 3D models (such as the famous
application Blender) it does not focus on the artistic aspects of 3D
modeling but instead on the CAD aspects. Thus it might be the application
you are looking for when you are planning to create 3D models of machine
parts but pretty sure is not what you are looking for when you are more
interested in creating computer-animated movies.

%prep
%autosetup -S git -n %{name}-%{name}-%{uversion}

# Unbundle polyclipping
rm -rf src/ext/polyclipping

%build
%qmake_qt5 VERSION=%{uversion} \
           PREFIX=%{_prefix} \
           CONFIG-=debug
%make_build

%if 0
# Build test suite
pushd tests
  cmake -DPYTHON_EXECUTABLE:STRING=%{__python3} .
  %make_build
popd
%endif
%install
%make_install INSTALL_ROOT=%{buildroot}

%check
# Run tests
pushd tests
  ctest %{?_smp_mflags} || : # let the tests fail, as some don't work on the BS
popd

%files
%doc COPYING README.md RELEASE_NOTES.md
%{_bindir}/%{name}
%{_metainfodir}/org.%{name}.OpenSCAD.appdata.xml
%{_datadir}/applications/%{name}.desktop
%{_datadir}/mime/packages/%{name}.xml
%{_iconsdir}/hicolor/*/apps/openscad.png
%{_datadir}/%{name}/
%{_mandir}/man1/%{name}.1*


%changelog
* Tue Jul 20 2021 neoclust <neoclust> 2021.01-1.2.mga8
+ Revision: 1737225
- Rebuild against new lib3mf major
- New version: Fixes CVE-2020-28599  (mga#28537)
- Add P100: Fixes CVE-2020-28599 (mga#28537)
+ akien <akien>
- Rebuild for cgal 5.2.1 (header-only library)

* Thu Dec 31 2020 wally <wally> 2019.05-10.mga8
+ Revision: 1666796
- rebuild for boost 1.75.0

* Sun Dec 20 2020 wally <wally> 2019.05-9.mga8
+ Revision: 1662038
- rebuild for boost 1.74.0

* Thu Dec 17 2020 umeabot <umeabot> 2019.05-8.mga8
+ Revision: 1659219
- Rebuild for new Qt5

* Wed Dec 02 2020 luigiwalser <luigiwalser> 2019.05-7.mga8
+ Revision: 1651365
- rebuild for glew

* Sun May 03 2020 wally <wally> 2019.05-6.mga8
+ Revision: 1578453
- rebuild for boost 1.73.0

* Thu Feb 20 2020 umeabot <umeabot> 2019.05-5.mga8
+ Revision: 1545113
- Mageia 8 Mass Rebuild

* Mon Jan 27 2020 daviddavid <daviddavid> 2019.05-4.mga8
+ Revision: 1484067
- add patch to fix a crash with empty STL/PNG import
- add patch to fix missing header (include <stack>)
+ wally <wally>
- rebuild for boost 1.72.0

* Sat Jan 04 2020 daviddavid <daviddavid> 2019.05-3.mga8
+ Revision: 1476533
- enable lib3MF support

* Fri Jan 03 2020 daviddavid <daviddavid> 2019.05-2.mga8
+ Revision: 1475886
- new version: 2019.05
- switch tests to python3
- split out all Qt5 BRs and add a new one on Qt5Gamepad

* Sun Mar 31 2019 umeabot <umeabot> 2015.03.3-16.mga7
+ Revision: 1383648
- Qt5 Rebuild

* Tue Feb 19 2019 daviddavid <daviddavid> 2015.03.3-15.mga7
+ Revision: 1368523
- rebuild for new qscintilla 2.11.1

* Tue Oct 16 2018 wally <wally> 2015.03.3-14.mga7
+ Revision: 1321073
- rebuild for new boost 1.68.0

* Sun Sep 23 2018 umeabot <umeabot> 2015.03.3-13.mga7
+ Revision: 1300032
- Mageia 7 Mass Rebuild

* Thu Apr 19 2018 daviddavid <daviddavid> 2015.03.3-12.mga7
+ Revision: 1220179
- rebuild for new qscintilla 2.10.4

* Tue Feb 20 2018 kekepower <kekepower> 2015.03.3-11.mga7
+ Revision: 1203581
- Rebuild for new mpfr

* Tue Jan 23 2018 wally <wally> 2015.03.3-10.mga7
+ Revision: 1196621
- add patch from usptream to fix build with Qt > 5.7.1
- rebuild for new boost
+ tv <tv>
- rebuild for boost 1.65
- rebuild with latest boost
- rebuild for new libglew

* Tue Jan 31 2017 barjac <barjac> 2015.03.3-6.mga6
+ Revision: 1084308
- Rebuild for eigen3

* Sat Oct 29 2016 akien <akien> 2015.03.3-5.mga6
+ Revision: 1063912
- Rebuild for cgal 4.9

* Sun Sep 25 2016 akien <akien> 2015.03.3-4.mga6
+ Revision: 1055955
- Rebuild for polyclipping 6.4

* Sun Apr 24 2016 akien <akien> 2015.03.3-1.mga6
+ Revision: 1005908
- Version 2015.03-3

* Sun Feb 14 2016 joequant <joequant> 2015.03.2-4.mga6
+ Revision: 960315
- Work around flex build problem
  This works around the build problem in bug 1546 in the openscad github
  site.  The qtmake doesn't add a prefix arg for flex.
+ akien <akien>
- Disable debug build (upstream GH-1045)
- Use system polyclipping (Fedora patch)
+ daviddavid <daviddavid>
- rebuild for new boost 1.60.0

* Sun Dec 13 2015 akien <akien> 2015.03.2-1.mga6
+ Revision: 910083
- Version 2015.03-2

* Thu Oct 22 2015 ycantin <ycantin> 2015.03.1-6.mga6
+ Revision: 894247
- qt5 build
- rebuild for new boost
+ fwang <fwang>
- rebuild for new boost
+ tv <tv>
- rebuild for new boost

* Wed Sep 09 2015 fwang <fwang> 2015.03.1-3.mga6
+ Revision: 874670
- rebuild for new qscintilla

* Sun Aug 30 2015 akien <akien> 2015.03.1-2.mga6
+ Revision: 871203
- Rebuild for boost 1.58.0

* Wed Jun 24 2015 akien <akien> 2015.03.1-1.mga6
+ Revision: 842305
- Requires qscintilla, currently only packaged for Qt4
- Version 2015.03-1

* Wed Oct 15 2014 umeabot <umeabot> 2014.03-3.mga5
+ Revision: 739881
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2014.03-2.mga5
+ Revision: 683239
- Mageia 5 Mass Rebuild

* Mon Sep 08 2014 akien <akien> 2014.03-1.mga5
+ Revision: 673784
- Continue when tests fail on the BS
- Add missing BR on x11-server-xvfb
- Enable test suite building
+ luigiwalser <luigiwalser>
- rebuild for glew

* Thu Jun 12 2014 akien <akien> 2014.03-0.mga5
+ Revision: 635892
- Disable building of the test suite for now
- import source RPM from Fedora

